@@ -350,8 +350,8 @@ class HanLPClient(object):
             A dictionary containing each keyphrase and its ranking score :math:`s`, :math:`s \in [0, 1]`.
         """
         assert text, 'Text has to be specified.'
-        return self._send_post_json(self._url + '/keyphrase_extraction', {
-            'text': text,
-            'language': language or self._language,
-            'topk': topk,
+        scores = self._send_post_json(self._url + '/keyphrase_extraction', {
+            'text': text, 'language': language or self._language, 'topk': topk,
         })
+        scores = dict(sorted(scores.items(), key=lambda x: (x[1], x[0]), reverse=True))
+        return scores
